@@ -1,6 +1,4 @@
-"""
-Functions for writing to pvsite db
-"""
+"""Functions for writing to pvsite db."""
 
 import datetime as dt
 import logging
@@ -10,6 +8,7 @@ import dateutil.parser as dp
 import numpy.typing as npt
 import pandas as pd
 import sqlalchemy.orm as sa_orm
+
 from pvsite_datamodel.read.site import get_site_by_uuid
 from pvsite_datamodel.sqlmodels import ForecastSQL, ForecastValueSQL
 from pvsite_datamodel.write.datetime_intervals import get_or_else_create_datetime_interval
@@ -20,8 +19,7 @@ from pvsite_datamodel.write.utils import WrittenRow
 def insert_forecast_values(
     session: sa_orm.Session, df_forecast_values: pd.DataFrame, forecast_version: str = "0.0.0"
 ) -> list[WrittenRow]:
-    """
-    Inserts a dataframe of forecast values into the database.
+    """Insert a dataframe of forecast values into the database.
 
     :param session: sqlalchemy session for interacting with the database
     :param df_forecast_values: pandas dataframe with columns
@@ -29,7 +27,6 @@ def insert_forecast_values(
     :param forecast_version: the version of the model used to create the forecast
     :return list[WrittenRow]: list of added rows to DB
     """
-
     # Track rows added to DB
     written_rows: list[WrittenRow] = []
 
